Enum intrepid_core::Frame

source ·
pub enum Frame {
    Unit,
    Error(Bytes),
    Anonymous(Bytes),
    Message(MessageFrame),
}
A frame that can be processed by an action.

Variants



Unit

A unit frame, with nothing in it.



Error(Bytes)

An error frame.



Anonymous(Bytes)

An unaddressed chunk of bytes.



Message(MessageFrame)

An addressed frame.

Implementations

source

impl Frame

source

pub fn new(bytes: impl Into<Bytes>) -> Self

Create a new frame from a given set of bytes.

source

pub fn message( uri: impl AsRef<str>, data: impl Into<Frame>, meta: impl Into<Frame>, ) -> Self

Create a message frame.

source

pub fn len(&self) -> usize

The length of the frame in bytes.

source

pub fn is_empty(&self) -> bool

Check if the frame is empty.

source

pub fn as_bytes(&self) -> &[u8]

Get a reference to the frame as a slice of bytes.

source

pub fn into_bytes(self) -> Bytes

Convert the frame’s body into a vector of bytes.