Enum intrepid_core::System
source · pub enum System<Status, State> {
Direct(Direct<Status, State>),
Dispatch(Dispatch<Status, State>),
Routed(Routed<Status, State>),
}Expand description
A system is a collection of actions that can be invoked as services.
Variants
Direct(Direct<Status, State>)
An unordered system that invokes all actions.
Dispatch(Dispatch<Status, State>)
A system that routes frames to actions fully matching patterns.
Routed(Routed<Status, State>)
A system that routes frames to matching patterns.
Implementations
sourceimpl<State> System<Open, State>
impl<State> System<Open, State>
sourcepub fn with_state(&self, state: State) -> System<Stateful<State>, State>
pub fn with_state(&self, state: State) -> System<Stateful<State>, State>
Transition to a stateful system with a given state.
sourceimpl System<Open, ()>
impl System<Open, ()>
sourcepub fn without_state(self) -> System<Stateless, ()>
pub fn without_state(self) -> System<Stateless, ()>
If we know that the state is empty, we know that we can transition to a stateless system. Transition to a stateless system.
sourcepub fn handle_frame(self, frame: Frame) -> FrameFuture ⓘ
pub fn handle_frame(self, frame: Frame) -> FrameFuture ⓘ
Call the system with a frame.
sourceimpl<State> System<Stateful<State>, State>
impl<State> System<Stateful<State>, State>
sourcepub async fn handle_frame(self, frame: Frame) -> Result<Frame>
pub async fn handle_frame(self, frame: Frame) -> Result<Frame>
Call the system with a frame.
sourceimpl System<Stateless, ()>
impl System<Stateless, ()>
sourcepub fn handle_frame(self, frame: Frame) -> FrameFuture ⓘ
pub fn handle_frame(self, frame: Frame) -> FrameFuture ⓘ
Call the system with a frame.
sourceimpl<Status, State> System<Status, State>
impl<Status, State> System<Status, State>
sourcepub fn on_frame<ActionHandler, Args>(self, action: ActionHandler) -> Self
pub fn on_frame<ActionHandler, Args>(self, action: ActionHandler) -> Self
Add a frame handler to the system. This is a no-op for systems that do not support wildcard routing or only support specific patterns.
sourcepub fn on<ActionHandler, Args>(
self,
pattern: impl AsRef<str>,
action: ActionHandler,
) -> Self
pub fn on<ActionHandler, Args>( self, pattern: impl AsRef<str>, action: ActionHandler, ) -> Self
Add a uri bound or path bound handler to the system.
- Dispatch systems will match the pattern exactly.
- Routed systems will match the pattern as a path fragment.
sourcepub fn action_context(&self) -> ActionContext<State>
pub fn action_context(&self) -> ActionContext<State>
Get the action context for this system.