Struct intrepid_core::Message
source · pub struct Message(pub MessageFrame);Expand description
Retrieve a MessageFrame from a Frame, but only if the frame is a message.
Tuple Fields
0: MessageFrameTrait Implementations
sourceimpl<State> Extractor<State> for Message
impl<State> Extractor<State> for Message
sourcetype Error = MessageFrameError
type Error = MessageFrameError
The error type for this extractor. Anything that can be converted into an extractor error
can be used as an error type. Read more
sourcefn extract(frame: Frame, _: &ExtractContext<State>) -> Result<Self, Self::Error>
fn extract(frame: Frame, _: &ExtractContext<State>) -> Result<Self, Self::Error>
Take an frame and a state and return a result containing the extracted value or the frame.
sourcefn extract_from_frame_and_state(
frame: Frame,
context: &ExtractContext<State>,
) -> Result<Self>
fn extract_from_frame_and_state( frame: Frame, context: &ExtractContext<State>, ) -> Result<Self>
Extract a value from a frame and state, returning a result containing the extracted value
or an error coerced into a
crate::Error.Auto Trait Implementations
impl !Freeze for Message
impl RefUnwindSafe for Message
impl Send for Message
impl Sync for Message
impl Unpin for Message
impl UnwindSafe for Message