Struct intrepid_core::Ready

source ·
pub struct Ready<ActionHandler: Clone, Args: Clone, State: Clone> {
    pub action: ActionHandler,
    pub state: State,
    /* private fields */
}
A Ready type state represents an action which has a handler and a state, and can be invoked

Fields

action: ActionHandler

The action handler for this ready status struct.

state: State

The state the ready status contains.

Implementations

source

impl<ActionHandler, Args, State> Ready<ActionHandler, Args, State>
where ActionHandler: Handler<Args, State> + Clone + Send + 'static, Args: Clone + Send + 'static, State: Clone + Send + 'static,

source

pub fn new(action: ActionHandler, state: State) -> Self

Create a new Ready state from an action and a state.