Struct intrepid_core::Router
source · pub struct Router<State> { /* private fields */ }Expand description
A router for actions that can be invoked as services.
Implementations
sourceimpl<State> Router<State>
impl<State> Router<State>
sourcepub fn capture<T>(&self, path: impl AsRef<str>) -> Result<T, PathError>where
T: DeserializeOwned,
pub fn capture<T>(&self, path: impl AsRef<str>) -> Result<T, PathError>where
T: DeserializeOwned,
Given a path, attempt to deserialize the path fragments into a given type.
sourcepub fn handle_frame_with_state(&self, frame: Frame, state: State) -> FrameFuture ⓘ
pub fn handle_frame_with_state(&self, frame: Frame, state: State) -> FrameFuture ⓘ
Call an action with a given state.
sourcepub fn insert<ActionHandler, Args>(
&mut self,
route: impl Into<String>,
given_action: ActionHandler,
) -> Result<()>
pub fn insert<ActionHandler, Args>( &mut self, route: impl Into<String>, given_action: ActionHandler, ) -> Result<()>
Insert a new action into the router, turning it into an [ActionEndpoint].