Struct intrepid_core::State

source ·
pub struct State<T: Clone>(pub T);
Retrieve the state an action expects. This has the side-effect of creating a state dependency for the action. All actions in a given system must share the same state type.

Tuple Fields

0: T