Actionable

Trait Actionable 

pub trait Actionable<GivenState>:
    DynClone
    + Send
    + Sync
    + 'static {
    // Required method
    fn into_actionable(self: Box<Self>, state: GivenState) -> ActiveAction;
}
Allows actions to be type erased into dynamic boxed containers.

Required Methods

fn into_actionable(self: Box<Self>, state: GivenState) -> ActiveAction

Take a given boxed action and state and return an active actionable.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<ActionHandler, Args, State> Actionable<State> for CandidateAction<ActionHandler, Args, State>
where ActionHandler: Handler<Args, State> + Clone + Send + Sync + 'static, Args: Clone + Send + Sync + 'static, State: Clone + Send + Sync + 'static,