Struct intrepid_core::Ready
source · pub struct Ready<ActionHandler: Clone, Args: Clone, State: Clone> {
pub action: ActionHandler,
pub state: State,
/* private fields */
}Expand description
A Ready type state represents an action which has a handler and a state, and can be
invoked
Fields
action: ActionHandlerThe action handler for this ready status struct.
state: StateThe state the ready status contains.
Implementations